@@ -22,7 +22,7 @@ def intercept_worker(fn, *args, **kwargs):
         raise e
     finally:
         if ctx:
-            end_interceptor()
+            end_interceptor(ctx=ctx)
 
 def instrument_nameko_spawn_worker(module):
     def wrapper(fn):
