@@ -123,6 +123,8 @@ class UseridUtil(object):
     @staticmethod
     def getRemoteAddr(args):
         if conf.trace_http_client_ip_header_key:
-            return UseridUtil.getHeader(args, conf.trace_http_client_ip_header_key)
-        else:
-            return UseridUtil.getHeader(args, "REMOTE_ADDR")
\ No newline at end of file
+            header_val = UseridUtil.getHeader(args, conf.trace_http_client_ip_header_key)
+            if header_val:
+                return header_val.split(',')[0].strip()
+
+        return UseridUtil.getHeader(args, "REMOTE_ADDR")
\ No newline at end of file
